<?php
/*
* page settings
*/
function agrikon_get_all_elementor_templates($type = null)
{
    $args = [
        'post_type' => 'elementor_library',
        'posts_per_page' => -1,
    ];
    if ($type) {
        $args['tax_query'] = [
            [
                'taxonomy' => 'elementor_library_type',
                'field' => 'slug',
                'terms' => $type
            ]
        ];
    }
    $page_templates = get_posts($args);
    $options = array();
    if (!empty($page_templates) && !is_wp_error($page_templates)) {
        foreach ($page_templates as $post) {
            $options[$post->ID] = $post->post_title;
        }
    }
    return $options;
}
add_action( 'elementor/documents/register_controls', 'agrikon_add_theme_skin_to_page_settings' );
function agrikon_add_theme_skin_to_page_settings( $document )
{
    if ( ! $document instanceof \Elementor\Core\DocumentTypes\PageBase || ! $document::get_property( 'has_elements' ) ) {
        return;
    }
    $document->start_controls_section( 'agrikon_page_settings_controls_section',
        [
            'label' => esc_html__( 'PAGE SETTINGS', 'agrikon' ),
            'tab' => \Elementor\Controls_Manager::TAB_SETTINGS
        ]
    );
    $document->add_control( 'agrikon_elementor_page_header_settings_heading',
        [
            'label' => esc_html__( 'AGRIKON HEADER', 'agrikon' ),
            'type' => \Elementor\Controls_Manager::HEADING,
            'separator' => 'before',
        ]
    );
    $document->add_control( 'agrikon_elementor_hide_page_header',
        [
            'label' => esc_html__( 'Hide Page Header', 'agrikon' ),
            'type' => \Elementor\Controls_Manager::SWITCHER,
            'return_value' => 'yes',
            'default' => 'no',
        ]
    );
    $document->add_control( 'agrikon_page_header_template',
        [
            'label' => esc_html__( 'Select Header Template', 'agrikon' ),
            'type' => \Elementor\Controls_Manager::SELECT2,
            'default' => '',
            'multiple' => false,
            'options' => agrikon_get_all_elementor_templates(),
            'condition' => [ 'agrikon_elementor_hide_page_header!' => 'yes' ]
        ]
    );
    $document->add_control( 'agrikon_elementor_page_footer_settings_heading',
        [
            'label' => esc_html__( 'AGRIKON FOOTER', 'agrikon' ),
            'type' => \Elementor\Controls_Manager::HEADING,
            'separator' => 'before',
        ]
    );
    $document->add_control( 'agrikon_elementor_hide_page_footer',
        [
            'label' => esc_html__( 'Hide Footer', 'agrikon' ),
            'type' => \Elementor\Controls_Manager::SWITCHER,
            'return_value' => 'yes',
            'default' => 'no',
        ]
    );
    $document->add_control( 'agrikon_page_footer_template',
        [
            'label' => esc_html__( 'Select Footer Template', 'agrikon' ),
            'type' => \Elementor\Controls_Manager::SELECT2,
            'default' => '',
            'multiple' => false,
            'options' => agrikon_get_all_elementor_templates(),
            'condition' => [ 'agrikon_page_footer_template!' => 'yes' ]
        ]
    );
    $document->end_controls_section();
}
